summaryrefslogtreecommitdiff
path: root/src/mongo/db/curop.h
diff options
context:
space:
mode:
authorLouis Williams <louis.williams@mongodb.com>2018-03-21 11:37:40 -0400
committerLouis Williams <louis.williams@mongodb.com>2018-03-23 13:09:35 -0400
commit8823c3dfe826cbc3bf72208025010abc7d01c80e (patch)
tree2bbc7c4b434afda5008835fe9c4611277f109403 /src/mongo/db/curop.h
parentb388395c255f7144dff2b582ed7ad1227f7351ff (diff)
downloadmongo-8823c3dfe826cbc3bf72208025010abc7d01c80e.tar.gz
SERVER-33309 SERVER-33310 Handle WT_PREPARE_CONFLICT. Add methods in
WiredTigerSessionCache to wait and notify on prepared units of work.
Diffstat (limited to 'src/mongo/db/curop.h')
-rw-r--r--src/mongo/db/curop.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/mongo/db/curop.h b/src/mongo/db/curop.h
index 2cdefe4d859..c68f68a5c0e 100644
--- a/src/mongo/db/curop.h
+++ b/src/mongo/db/curop.h
@@ -113,9 +113,10 @@ public:
// The following metrics are initialized with 0 rather than -1 in order to simplify use by the
// CRUD path.
- long long nmoved{0}; // updates resulted in a move (moves are expensive)
- long long keysInserted{0}; // Number of index keys inserted.
- long long keysDeleted{0}; // Number of index keys removed.
+ long long nmoved{0}; // updates resulted in a move (moves are expensive)
+ long long keysInserted{0}; // Number of index keys inserted.
+ long long keysDeleted{0}; // Number of index keys removed.
+ long long prepareReadConflicts{0}; // Number of read conflicts caused by a prepared transaction
long long writeConflicts{0};
BSONObj execStats; // Owned here.